# Contributing guide
Want to contribute to `fgivenx`? Awesome!
There are many ways you can contribute, see below.

## Opening issues
Open an issue to report bugs or to propose new features.

## Proposing pull requests
Pull requests are very welcome. Note that if you are going to propose drastic changes, be sure to open an issue for discussion first, to make sure that your PR will be accepted before you spend effort coding it.
